@@ -21,7 +21,7 @@ __author__ = 'Sandro Santilli'
 __date__ = 'May 2017'
 __copyright__ = '(C) 2017, Sandro Santilli'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 import os
 import re
@@ -79,7 +79,7 @@ class TestDBManagerPostgisPlugin(unittest.TestCase):
                 if tab.type == Table.RasterType:
                     raster_tables_count += 1
                     gdalUri = tab.gdalUri()
-                    m = re.search(' dbname=([^ ]*) ', gdalUri)
+                    m = re.search(' dbname=\'([^ ]*)\' ', gdalUri)
                     self.assertTrue(m)
                     actual_dbname = m.group(1)
                     self.assertEqual(actual_dbname, expected_dbname)
