@@ -23,15 +23,15 @@ __copyright__ = '(C) 2017, Médéric Ribreux'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'a86bec25ebddd442bde3c6fe8ee761b22b36c26c'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 from .v_net import incorporatePoints, variableOutput
 
 
-def processCommand(alg, parameters, context):
-    incorporatePoints(alg, parameters, context)
+def processCommand(alg, parameters, context, feedback):
+    incorporatePoints(alg, parameters, context, feedback)
 
 
-def processOutputs(alg, parameters, context):
+def processOutputs(alg, parameters, context, feedback):
     outputParameter = {'output': ['output', 'line', 1, True]}
     variableOutput(alg, outputParameter, parameters, context)
