@@ -23,12 +23,13 @@ __copyright__ = '(C) 2016, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive323
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 from qgis.core import (QgsWkbTypes,
                        QgsExpression,
                        QgsGeometry,
                        QgsProcessing,
+                       QgsProcessingAlgorithm,
                        QgsProcessingException,
                        QgsProcessingParameterBoolean,
                        QgsProcessingParameterEnum,
@@ -51,6 +52,9 @@ class GeometryByExpression(QgisFeatureBasedAlgorithm):
     def groupId(self):
         return 'vectorgeometry'
 
+    def flags(self):
+        return super().flags() & ~QgsProcessingAlgorithm.FlagSupportsInPlaceEdits
+
     def __init__(self):
         super().__init__()
         self.geometry_types = [self.tr('Polygon'),
