@@ -23,7 +23,7 @@ __copyright__ = '(C) 2017, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 import os
 import math
@@ -162,15 +162,15 @@ class MinimumBoundingGeometry(QgisAlgorithm):
 
                 if type == 0:
                     # bounding boxes - calculate on the fly for efficiency
-                    if not f.attributes()[field_index] in bounds_dict:
-                        bounds_dict[f.attributes()[field_index]] = f.geometry().boundingBox()
+                    if not f[field_index] in bounds_dict:
+                        bounds_dict[f[field_index]] = f.geometry().boundingBox()
                     else:
-                        bounds_dict[f.attributes()[field_index]].combineExtentWith(f.geometry().boundingBox())
+                        bounds_dict[f[field_index]].combineExtentWith(f.geometry().boundingBox())
                 else:
-                    if not f.attributes()[field_index] in geometry_dict:
-                        geometry_dict[f.attributes()[field_index]] = [f.geometry()]
+                    if not f[field_index] in geometry_dict:
+                        geometry_dict[f[field_index]] = [f.geometry()]
                     else:
-                        geometry_dict[f.attributes()[field_index]].append(f.geometry())
+                        geometry_dict[f[field_index]].append(f.geometry())
 
                 feedback.setProgress(int(current * total))
 
