@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 import os
 from random import seed, uniform
@@ -31,16 +31,18 @@ from math import sqrt
 
 from qgis.PyQt.QtGui import QIcon
 from qgis.PyQt.QtCore import QVariant
-from qgis.core import (QgsFields,
+from qgis.core import (QgsApplication,
+                       QgsFields,
                        QgsFeatureSink,
                        QgsField,
                        QgsFeature,
                        QgsWkbTypes,
                        QgsGeometry,
-                       QgsPointXY,
+                       QgsPoint,
                        QgsProcessing,
+                       QgsProcessingException,
+                       QgsProcessingParameterDistance,
                        QgsProcessingParameterExtent,
-                       QgsProcessingParameterNumber,
                        QgsProcessingParameterBoolean,
                        QgsProcessingParameterCrs,
                        QgsProcessingParameterFeatureSink)
@@ -61,7 +63,10 @@ class RegularPoints(QgisAlgorithm):
     CRS = 'CRS'
 
     def icon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'ftools', 'regular_points.png'))
+        return QgsApplication.getThemeIcon("/algorithms/mAlgorithmRegularPoints.svg")
+
+    def svgIconPath(self):
+        return QgsApplication.iconPath("/algorithms/mAlgorithmRegularPoints.svg")
 
     def group(self):
         return self.tr('Vector creation')
@@ -75,10 +80,10 @@ class RegularPoints(QgisAlgorithm):
     def initAlgorithm(self, config=None):
         self.addParameter(QgsProcessingParameterExtent(self.EXTENT,
                                                        self.tr('Input extent'), optional=False))
-        self.addParameter(QgsProcessingParameterNumber(self.SPACING,
-                                                       self.tr('Point spacing/count'), QgsProcessingParameterNumber.Double, 100, False, 0.000001, 999999999.999999999))
-        self.addParameter(QgsProcessingParameterNumber(self.INSET,
-                                                       self.tr('Initial inset from corner (LH side)'), QgsProcessingParameterNumber.Double, 0.0, False, 0.0, 9999.9999))
+        self.addParameter(QgsProcessingParameterDistance(self.SPACING,
+                                                         self.tr('Point spacing/count'), 100, self.CRS, False, 0.000001))
+        self.addParameter(QgsProcessingParameterDistance(self.INSET,
+                                                         self.tr('Initial inset from corner (LH side)'), 0.0, self.CRS, False, 0.0))
         self.addParameter(QgsProcessingParameterBoolean(self.RANDOMIZE,
                                                         self.tr('Apply random offset to point spacing'), False))
         self.addParameter(QgsProcessingParameterBoolean(self.IS_SPACING,
@@ -107,6 +112,8 @@ class RegularPoints(QgisAlgorithm):
 
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
                                                fields, QgsWkbTypes.Point, crs)
+        if sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
         if randomize:
             seed()
@@ -122,6 +129,7 @@ class RegularPoints(QgisAlgorithm):
         f.setFields(fields)
 
         count = 0
+        id = 0
         total = 100.0 / (area / pSpacing)
         y = extent.yMaximum() - inset
 
@@ -136,19 +144,22 @@ class RegularPoints(QgisAlgorithm):
                     break
 
                 if randomize:
-                    geom = QgsGeometry().fromPointXY(QgsPointXY(
+                    geom = QgsGeometry(QgsPoint(
                         uniform(x - (pSpacing / 2.0), x + (pSpacing / 2.0)),
                         uniform(y - (pSpacing / 2.0), y + (pSpacing / 2.0))))
                 else:
-                    geom = QgsGeometry().fromPointXY(QgsPointXY(x, y))
+                    geom = QgsGeometry(QgsPoint(x, y))
 
                 if extent_engine.intersects(geom.constGet()):
-                    f.setAttribute('id', count)
+                    f.setAttributes([id])
                     f.setGeometry(geom)
                     sink.addFeature(f, QgsFeatureSink.FastInsert)
                     x += pSpacing
-                    count += 1
-                    feedback.setProgress(int(count * total))
+                    id += 1
+
+                count += 1
+                feedback.setProgress(int(count * total))
+
             y = y - pSpacing
 
         return {self.OUTPUT: dest_id}
