@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Joshua Arnott'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 import os
 
@@ -35,11 +35,14 @@ from qgis.core import (QgsFields,
                        QgsGeometry,
                        QgsProcessing,
                        QgsProcessingUtils,
+                       QgsProcessingException,
                        QgsProcessingParameterBoolean,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterEnum,
                        QgsProcessingParameterField,
-                       QgsProcessingParameterFeatureSink)
+                       QgsProcessingParameterFeatureSink,
+                       QgsProcessingParameterString,
+                       QgsProcessingOutputNumber)
 
 from processing.algs.qgis.QgisAlgorithm import QgisAlgorithm
 from processing.tools import vector
@@ -54,10 +57,10 @@ class SpatialJoin(QgisAlgorithm):
     JOIN_FIELDS = "JOIN_FIELDS"
     METHOD = "METHOD"
     DISCARD_NONMATCHING = "DISCARD_NONMATCHING"
+    PREFIX = "PREFIX"
     OUTPUT = "OUTPUT"
-
-    def icon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'ftools', 'join_location.png'))
+    NON_MATCHING = "NON_MATCHING"
+    JOINED_COUNT = "JOINED_COUNT"
 
     def group(self):
         return self.tr('Vector general')
@@ -72,7 +75,7 @@ class SpatialJoin(QgisAlgorithm):
         self.predicates = (
             ('intersects', self.tr('intersects')),
             ('contains', self.tr('contains')),
-            ('equals', self.tr('equals')),
+            ('isEqual', self.tr('equals')),
             ('touches', self.tr('touches')),
             ('overlaps', self.tr('overlaps')),
             ('within', self.tr('within')),
@@ -87,8 +90,8 @@ class SpatialJoin(QgisAlgorithm):
                                     'crosses': 'crosses'}
 
         self.methods = [
-            self.tr('Create separate feature for each located feature'),
-            self.tr('Take attributes of the first located feature only')
+            self.tr('Create separate feature for each located feature (one-to-many)'),
+            self.tr('Take attributes of the first located feature only (one-to-one)')
         ]
 
         self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT,
@@ -117,8 +120,22 @@ class SpatialJoin(QgisAlgorithm):
         self.addParameter(QgsProcessingParameterBoolean(self.DISCARD_NONMATCHING,
                                                         self.tr('Discard records which could not be joined'),
                                                         defaultValue=False))
+        self.addParameter(QgsProcessingParameterString(self.PREFIX,
+                                                       self.tr('Joined field prefix'), optional=True))
         self.addParameter(QgsProcessingParameterFeatureSink(self.OUTPUT,
-                                                            self.tr('Joined layer')))
+                                                            self.tr('Joined layer'),
+                                                            QgsProcessing.TypeVectorAnyGeometry,
+                                                            defaultValue=None, optional=True, createByDefault=True))
+
+        non_matching = QgsProcessingParameterFeatureSink(self.NON_MATCHING,
+                                                         self.tr('Unjoinable features from first layer'),
+                                                         QgsProcessing.TypeVectorAnyGeometry,
+                                                         defaultValue=None, optional=True, createByDefault=False)
+        # TODO GUI doesn't support advanced outputs yet
+        # non_matching.setFlags(non_matching.flags() | QgsProcessingParameterDefinition.FlagAdvanced )
+        self.addParameter(non_matching)
+
+        self.addOutput(QgsProcessingOutputNumber(self.JOINED_COUNT, self.tr("Number of joined features from input table")))
 
     def name(self):
         return 'joinattributesbylocation'
@@ -131,10 +148,17 @@ class SpatialJoin(QgisAlgorithm):
 
     def processAlgorithm(self, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
+
         join_source = self.parameterAsSource(parameters, self.JOIN, context)
+        if join_source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.JOIN))
+
         join_fields = self.parameterAsFields(parameters, self.JOIN_FIELDS, context)
         method = self.parameterAsEnum(parameters, self.METHOD, context)
         discard_nomatch = self.parameterAsBool(parameters, self.DISCARD_NONMATCHING, context)
+        prefix = self.parameterAsString(parameters, self.PREFIX, context)
 
         source_fields = source.fields()
         fields_to_join = QgsFields()
@@ -149,10 +173,25 @@ class SpatialJoin(QgisAlgorithm):
                 if idx >= 0:
                     fields_to_join.append(join_source.fields().at(idx))
 
+        if prefix:
+            prefixed_fields = QgsFields()
+            for i in range(len(fields_to_join)):
+                field = fields_to_join[i]
+                field.setName(prefix + field.name())
+                prefixed_fields.append(field)
+            fields_to_join = prefixed_fields
+
         out_fields = QgsProcessingUtils.combineFields(source_fields, fields_to_join)
 
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
-                                               out_fields, source.wkbType(), source.sourceCrs())
+                                               out_fields, source.wkbType(), source.sourceCrs(), QgsFeatureSink.RegeneratePrimaryKey)
+        if self.OUTPUT in parameters and parameters[self.OUTPUT] is not None and sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
+
+        (non_matching_sink, non_matching_dest_id) = self.parameterAsSink(parameters, self.NON_MATCHING, context,
+                                                                         source.fields(), source.wkbType(), source.sourceCrs(), QgsFeatureSink.RegeneratePrimaryKey)
+        if self.NON_MATCHING in parameters and parameters[self.NON_MATCHING] is not None and non_matching_sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.NON_MATCHING))
 
         # do the join
 
@@ -163,7 +202,7 @@ class SpatialJoin(QgisAlgorithm):
                       self.parameterAsEnums(parameters, self.PREDICATE, context)]
 
         remaining = set()
-        if not discard_nomatch:
+        if not discard_nomatch or non_matching_sink is not None:
             remaining = set(source.allFeatureIds())
 
         added_set = set()
@@ -172,6 +211,9 @@ class SpatialJoin(QgisAlgorithm):
         features = join_source.getFeatures(request)
         total = 100.0 / join_source.featureCount() if join_source.featureCount() else 0
 
+        joined_count = 0
+        unjoined_count = 0
+
         for current, f in enumerate(features):
             if feedback.isCanceled():
                 break
@@ -192,7 +234,7 @@ class SpatialJoin(QgisAlgorithm):
 
                 join_attributes = []
                 for a in join_field_indexes:
-                    join_attributes.append(f.attributes()[a])
+                    join_attributes.append(f[a])
 
                 if engine is None:
                     engine = QgsGeometry.createGeometryEngine(f.geometry().constGet())
@@ -202,21 +244,33 @@ class SpatialJoin(QgisAlgorithm):
                     if getattr(engine, predicate)(test_feat.geometry().constGet()):
                         added_set.add(test_feat.id())
 
-                        # join attributes and add
-                        attributes = test_feat.attributes()
-                        attributes.extend(join_attributes)
-                        output_feature = test_feat
-                        output_feature.setAttributes(attributes)
-                        sink.addFeature(output_feature, QgsFeatureSink.FastInsert)
+                        if sink is not None:
+                            # join attributes and add
+                            attributes = test_feat.attributes()
+                            attributes.extend(join_attributes)
+                            output_feature = test_feat
+                            output_feature.setAttributes(attributes)
+                            sink.addFeature(output_feature, QgsFeatureSink.FastInsert)
                         break
 
             feedback.setProgress(int(current * total))
 
-        if not discard_nomatch:
+        if not discard_nomatch or non_matching_sink is not None:
             remaining = remaining.difference(added_set)
             for f in source.getFeatures(QgsFeatureRequest().setFilterFids(list(remaining))):
                 if feedback.isCanceled():
                     break
-                sink.addFeature(f, QgsFeatureSink.FastInsert)
+                if sink is not None:
+                    sink.addFeature(f, QgsFeatureSink.FastInsert)
+                if non_matching_sink is not None:
+                    non_matching_sink.addFeature(f, QgsFeatureSink.FastInsert)
 
-        return {self.OUTPUT: dest_id}
+        result = {}
+        if sink is not None:
+            result[self.OUTPUT] = dest_id
+        if non_matching_sink is not None:
+            result[self.NON_MATCHING] = non_matching_dest_id
+
+        result[self.JOINED_COUNT] = len(added_set)
+
+        return result
