@@ -24,7 +24,7 @@ __copyright__ = '(C) 2017, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 from qgis.core import (QgsProcessing,
                        QgsProviderRegistry,
@@ -68,18 +68,12 @@ def getFileFilter(param):
     elif param.type() == 'raster':
         return QgsProviderRegistry.instance().fileRasterFilters()
     elif param.type() == 'rasterDestination':
-        if param.provider() is not None:
-            exts = param.provider().supportedOutputRasterLayerExtensions()
-        else:
-            exts = QgsRasterFileWriter.supportedFormatExtensions()
+        exts = param.supportedOutputRasterLayerExtensions()
         for i in range(len(exts)):
             exts[i] = tr('{0} files (*.{1})', 'ParameterRaster').format(exts[i].upper(), exts[i].lower())
         return ';;'.join(exts) + ';;' + tr('All files (*.*)')
     elif param.type() in ('sink', 'vectorDestination'):
-        if param.provider() is not None:
-            exts = param.provider().supportedOutputVectorLayerExtensions()
-        else:
-            exts = QgsVectorFileWriter.supportedFormatExtensions()
+        exts = param.supportedOutputVectorLayerExtensions()
         for i in range(len(exts)):
             exts[i] = tr('{0} files (*.{1})', 'ParameterVector').format(exts[i].upper(), exts[i].lower())
         return ';;'.join(exts) + ';;' + tr('All files (*.*)')
