@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
+__revision__ = '2f64a3c4e74022c5555ee19862f034ffacc2b5fe'
 
 from qgis.core import (NULL,
                        QgsFeatureRequest)
@@ -76,7 +76,7 @@ def values(source, *attributes):
 
             # convert attribute value to number
             try:
-                v = float(feature.attributes()[i])
+                v = float(feature[i])
             except:
                 v = None
 
